@@ -35,7 +35,7 @@ func serverConsoleCommand() *core.Command {
 				Required:   true,
 				Positional: true,
 			},
-			core.ZoneArgSpec(),
+			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 		},
 		Run: instanceServerConsoleRun,
 	}
