@@ -1,14 +1,16 @@
-package instance
+package instance_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
+
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	blockCli "github.com/scaleway/scaleway-cli/v2/internal/namespaces/block/v1alpha1"
 	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
-	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
+	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/stretchr/testify/require"
 )
@@ -16,41 +18,41 @@ import (
 func Test_ServerVolumeUpdate(t *testing.T) {
 	t.Run("Attach", func(t *testing.T) {
 		t.Run("simple block volume", core.Test(&core.TestConfig{
-			Commands: GetCommands(),
+			Commands: instance.GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
 				createServerBionic("Server"),
-				createVolume("Volume", 10, instance.VolumeVolumeTypeBSSD),
+				createVolume("Volume", 10, instanceSDK.VolumeVolumeTypeBSSD),
 			),
 			Cmd: "scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .Volume.ID }}",
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["1"].Size)
-				assert.Equal(t, instance.VolumeServerVolumeTypeBSSD, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
+				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size)
+				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size)
+				assert.Equal(t, instanceSDK.VolumeServerVolumeTypeBSSD, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
 			},
 			AfterFunc:       deleteServer("Server"),
 			DisableParallel: true,
 		}))
 
 		t.Run("simple local volume", core.Test(&core.TestConfig{
-			Commands: GetCommands(),
+			Commands: instance.GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
 				createServerBionic("Server"),
-				createVolume("Volume", 10, instance.VolumeVolumeTypeLSSD),
+				createVolume("Volume", 10, instanceSDK.VolumeVolumeTypeLSSD),
 			),
 			Cmd: "scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .Volume.ID }}",
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["1"].Size)
-				assert.Equal(t, instance.VolumeServerVolumeTypeLSSD, ctx.Result.(*instance.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
+				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size)
+				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size)
+				assert.Equal(t, instanceSDK.VolumeServerVolumeTypeLSSD, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
 			},
 			AfterFunc:       deleteServer("Server"),
 			DisableParallel: true,
 		}))
 
 		t.Run("invalid volume UUID", core.Test(&core.TestConfig{
-			Commands:   GetCommands(),
+			Commands:   instance.GetCommands(),
 			BeforeFunc: createServerBionic("Server"),
 			Cmd:        "scw instance server attach-volume server-id={{ .Server.ID }} volume-id=11111111-1111-1111-1111-111111111111",
 			Check: core.TestCheckCombine(
@@ -63,14 +65,14 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 	})
 	t.Run("Detach", func(t *testing.T) {
 		t.Run("simple block volume", core.Test(&core.TestConfig{
-			Commands:   GetCommands(),
+			Commands:   instance.GetCommands(),
 			BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 			Cmd:        `scw instance server detach-volume volume-id={{ (index .Server.Volumes "1").ID }}`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				require.NoError(t, ctx.Err)
-				assert.NotZero(t, ctx.Result.(*instance.DetachVolumeResponse).Server.Volumes["0"])
-				assert.Nil(t, ctx.Result.(*instance.DetachVolumeResponse).Server.Volumes["1"])
-				assert.Equal(t, 1, len(ctx.Result.(*instance.DetachVolumeResponse).Server.Volumes))
+				assert.NotZero(t, ctx.Result.(*instanceSDK.DetachVolumeResponse).Server.Volumes["0"])
+				assert.Nil(t, ctx.Result.(*instanceSDK.DetachVolumeResponse).Server.Volumes["1"])
+				assert.Equal(t, 1, len(ctx.Result.(*instanceSDK.DetachVolumeResponse).Server.Volumes))
 			},
 			AfterFunc: core.AfterFuncCombine(
 				core.ExecAfterCmd(`scw instance volume delete {{ (index .Server.Volumes "1").ID }}`),
@@ -80,7 +82,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 		}))
 
 		t.Run("invalid volume UUID", core.Test(&core.TestConfig{
-			Commands:   GetCommands(),
+			Commands:   instance.GetCommands(),
 			BeforeFunc: createServerBionic("Server"),
 			Cmd:        "scw instance server detach-volume volume-id=11111111-1111-1111-1111-111111111111",
 			Check: core.TestCheckCombine(
@@ -96,12 +98,12 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 func Test_ServerUpdateCustom(t *testing.T) {
 	// IP cases.
 	t.Run("Try to remove ip from server without ip", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: createServerBionic("Server"),
 		Cmd:        "scw instance server update {{ .Server.ID }} ip=none",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				assert.Equal(t, (*instance.ServerIP)(nil), ctx.Result.(*instance.UpdateServerResponse).Server.PublicIP)
+				assert.Equal(t, (*instanceSDK.ServerIP)(nil), ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PublicIP)
 			},
 			core.TestCheckExitCode(0),
 		),
@@ -109,7 +111,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	}))
 
 	t.Run("Update server ip from server without ip", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createServerBionic("Server"),
 			createIP("IP"),
@@ -117,7 +119,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 		Cmd: "scw instance server update {{ .Server.ID }} ip={{ .IP.Address }}",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				assert.Equal(t, ctx.Meta["IP"].(*instance.IP).Address, ctx.Result.(*instance.UpdateServerResponse).Server.PublicIP.Address)
+				assert.Equal(t, ctx.Meta["IP"].(*instanceSDK.IP).Address, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PublicIP.Address)
 			},
 			core.TestCheckExitCode(0),
 		),
@@ -125,7 +127,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	}))
 
 	t.Run("Update server ip from server with ip", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createServerBionic("Server"),
 			createIP("IP1"),
@@ -139,12 +141,12 @@ func Test_ServerUpdateCustom(t *testing.T) {
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				// Test that the Server WAS attached to IP1.
 				assert.Equal(t,
-					ctx.Meta["IP1"].(*instance.IP).Address,
-					ctx.Meta["UpdatedServer"].(*instance.UpdateServerResponse).Server.PublicIP.Address)
+					ctx.Meta["IP1"].(*instanceSDK.IP).Address,
+					ctx.Meta["UpdatedServer"].(*instanceSDK.UpdateServerResponse).Server.PublicIP.Address)
 				// Test that the Server IS attached to IP2.
 				assert.Equal(t,
-					ctx.Meta["IP2"].(*instance.IP).Address,
-					ctx.Result.(*instance.UpdateServerResponse).Server.PublicIP.Address)
+					ctx.Meta["IP2"].(*instanceSDK.IP).Address,
+					ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PublicIP.Address)
 			},
 			core.TestCheckExitCode(0),
 		),
@@ -156,7 +158,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 
 	// Placement group cases.
 	t.Run("Update server placement-group-id from server with placement-group-id", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createPlacementGroup("PlacementGroup1"),
 			createPlacementGroup("PlacementGroup2"),
@@ -167,8 +169,8 @@ func Test_ServerUpdateCustom(t *testing.T) {
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Equal(t,
-					ctx.Meta["PlacementGroup2"].(*instance.PlacementGroup).ID,
-					ctx.Result.(*instance.UpdateServerResponse).Server.PlacementGroup.ID)
+					ctx.Meta["PlacementGroup2"].(*instanceSDK.PlacementGroup).ID,
+					ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PlacementGroup.ID)
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -180,7 +182,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 
 	// Security group cases.
 	t.Run("Update server security-group-id from server with security-group-id", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createSecurityGroup("SecurityGroup1"),
 			createSecurityGroup("SecurityGroup2"),
@@ -191,8 +193,8 @@ func Test_ServerUpdateCustom(t *testing.T) {
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				assert.Equal(t,
-					ctx.Meta["SecurityGroup2"].(*instance.SecurityGroup).ID,
-					ctx.Result.(*instance.UpdateServerResponse).Server.SecurityGroup.ID)
+					ctx.Meta["SecurityGroup2"].(*instanceSDK.SecurityGroup).ID,
+					ctx.Result.(*instanceSDK.UpdateServerResponse).Server.SecurityGroup.ID)
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -205,27 +207,27 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	// Volumes cases.
 	t.Run("Volumes", func(t *testing.T) {
 		t.Run("valid simple block volume", core.Test(&core.TestConfig{
-			Commands: GetCommands(),
+			Commands: instance.GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
 				createServerBionic("Server"),
-				createVolume("Volume", 10, instance.VolumeVolumeTypeBSSD),
+				createVolume("Volume", 10, instanceSDK.VolumeVolumeTypeBSSD),
 			),
 			Cmd: `scw instance server update {{ .Server.ID }} volume-ids.0={{ (index .Server.Volumes "0").ID }} volume-ids.1={{ .Volume.ID }}`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.UpdateServerResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.UpdateServerResponse).Server.Volumes["1"].Size)
+				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["0"].Size)
+				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["1"].Size)
 			},
 			AfterFunc: deleteServer("Server"),
 		}))
 
 		t.Run("detach all volumes", core.Test(&core.TestConfig{
-			Commands:   GetCommands(),
+			Commands:   instance.GetCommands(),
 			BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 			Cmd:        `scw instance server update {{ .Server.ID }} volume-ids=none`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 0, len(ctx.Result.(*instance.UpdateServerResponse).Server.Volumes))
+				assert.Equal(t, 0, len(ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes))
 			},
 			AfterFunc: core.AfterFuncCombine(
 				core.ExecAfterCmd(`scw instance volume delete {{ (index .Server.Volumes "0").ID }}`),
@@ -242,7 +244,7 @@ func Test_ServerDelete(t *testing.T) {
 	interactive.IsInteractive = true
 
 	t.Run("with all volumes", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
 		Check: core.TestCheckCombine(
@@ -253,7 +255,7 @@ func Test_ServerDelete(t *testing.T) {
 	}))
 
 	t.Run("only block volumes", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=block`,
 		Check: core.TestCheckCombine(
@@ -265,7 +267,7 @@ func Test_ServerDelete(t *testing.T) {
 	}))
 
 	t.Run("only local volumes", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local`,
 		Check: core.TestCheckCombine(
@@ -277,16 +279,16 @@ func Test_ServerDelete(t *testing.T) {
 	}))
 
 	t.Run("with none volumes", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=none`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				api := instance.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instance.Server)
-				_, err := api.GetVolume(&instance.GetVolumeRequest{
+				api := instanceSDK.NewAPI(ctx.Client)
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				_, err := api.GetVolume(&instanceSDK.GetVolumeRequest{
 					VolumeID: server.Volumes["0"].ID,
 				})
 				assert.NoError(t, err)
@@ -298,7 +300,7 @@ func Test_ServerDelete(t *testing.T) {
 
 	t.Run("with sbs volumes", core.Test(&core.TestConfig{
 		Commands: core.NewCommandsMerge(
-			GetCommands(),
+			instance.GetCommands(),
 			blockCli.GetCommands(),
 		),
 		BeforeFunc: core.BeforeFuncCombine(
