@@ -1,4 +1,4 @@
-package instance
+package instance_test
 
 import (
 	"os"
@@ -8,14 +8,15 @@ import (
 
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/sshconfig"
-	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
+	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 )
 
 func Test_SSHConfigInstall(t *testing.T) {
 	t.Run("Install config and create default", core.Test(&core.TestConfig{
 		TmpHomeDir: true,
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: createServerBionic("Server"),
 		Args:       []string{"scw", "instance", "ssh", "install-config"},
 		Check: core.TestCheckCombine(
@@ -27,7 +28,7 @@ func Test_SSHConfigInstall(t *testing.T) {
 			),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				server := ctx.Meta["Server"].(*instance.Server)
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
 
 				configPath := sshconfig.ConfigFilePath(ctx.Meta["HOME"].(string))
 				content, err := os.ReadFile(configPath)
@@ -44,7 +45,7 @@ func Test_SSHConfigInstall(t *testing.T) {
 
 	t.Run("Install config and include", core.Test(&core.TestConfig{
 		TmpHomeDir: true,
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			func(ctx *core.BeforeFuncCtx) error {
 				homeDir := ctx.Meta["HOME"].(string)
@@ -68,7 +69,7 @@ func Test_SSHConfigInstall(t *testing.T) {
 			),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				server := ctx.Meta["Server"].(*instance.Server)
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
 
 				defaultConfigPath := sshconfig.DefaultConfigFilePath(ctx.Meta["HOME"].(string))
 				content, err := os.ReadFile(defaultConfigPath)
