@@ -1,11 +1,13 @@
-package instance
+package instance_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
+
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
-	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
+	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 )
 
 // addSSHKey add an ssh key to server stored in meta with given key
@@ -13,10 +15,10 @@ import (
 //nolint:unparam
 func addSSHKey(serverKey string, sshKey string) core.BeforeFunc {
 	return func(ctx *core.BeforeFuncCtx) error {
-		server := ctx.Meta[serverKey].(*instance.Server)
-		tags := append(server.Tags, formatSSHKeyToTag(sshKey))
+		server := ctx.Meta[serverKey].(*instanceSDK.Server)
+		tags := append(server.Tags, instance.FormatSSHKeyToTag(sshKey))
 
-		resp, err := instance.NewAPI(ctx.Client).UpdateServer(&instance.UpdateServerRequest{
+		resp, err := instanceSDK.NewAPI(ctx.Client).UpdateServer(&instanceSDK.UpdateServerRequest{
 			Zone:     server.Zone,
 			ServerID: server.ID,
 			Tags:     &tags,
@@ -36,15 +38,15 @@ func Test_SSHKey(t *testing.T) {
 	sshKey2 := "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIOLfjymSzcwMG56dOUum91KzyuKlf4AI+S1fCmXI8P78 key2"
 
 	t.Run("Add key", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   instance.GetCommands(),
 		BeforeFunc: createServerBionic("Server"),
 		Args:       []string{"scw", "instance", "ssh", "add-key", "server-id={{.Server.ID}}", "public-key=" + sshKey},
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				server := ctx.Meta["Server"].(*instance.Server)
-				resp, err := instance.NewAPI(ctx.Client).GetServer(&instance.GetServerRequest{
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				resp, err := instanceSDK.NewAPI(ctx.Client).GetServer(&instanceSDK.GetServerRequest{
 					Zone:     server.Zone,
 					ServerID: server.ID,
 				})
@@ -55,7 +57,7 @@ func Test_SSHKey(t *testing.T) {
 		AfterFunc: deleteServer("Server"),
 	}))
 	t.Run("List keys", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createServerBionic("Server"),
 			addSSHKey("Server", sshKey),
@@ -74,7 +76,7 @@ func Test_SSHKey(t *testing.T) {
 		AfterFunc: deleteServer("Server"),
 	}))
 	t.Run("Remove key", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: instance.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
 			createServerBionic("Server"),
 			addSSHKey("Server", sshKey),
@@ -85,8 +87,8 @@ func Test_SSHKey(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				server := ctx.Meta["Server"].(*instance.Server)
-				resp, err := instance.NewAPI(ctx.Client).GetServer(&instance.GetServerRequest{
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				resp, err := instanceSDK.NewAPI(ctx.Client).GetServer(&instanceSDK.GetServerRequest{
 					Zone:     server.Zone,
 					ServerID: server.ID,
 				})
