@@ -1,14 +1,16 @@
-package k8s
+package k8s_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 )
 
 func Test_GetCluster(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   k8s.GetCommands(),
 		BeforeFunc: createCluster("get-cluster", "Cluster", kapsuleVersion, 1, "DEV1-M"),
 		Cmd:        "scw k8s cluster get {{ .Cluster.ID }}",
 		Check: core.TestCheckCombine(
@@ -21,7 +23,7 @@ func Test_GetCluster(t *testing.T) {
 
 func Test_WaitCluster(t *testing.T) {
 	t.Run("wait for pools", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
+		Commands:   k8s.GetCommands(),
 		BeforeFunc: createCluster("wait-cluster", "Cluster", kapsuleVersion, 1, "GP1-XS"),
 		Cmd:        "scw k8s cluster wait {{ .Cluster.ID }} wait-for-pools=true",
 		Check: core.TestCheckCombine(
