@@ -1,14 +1,16 @@
-package registry
+package registry_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/registry/v1"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 )
 
 func Test_Logout(t *testing.T) {
 	t.Run("docker", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: registry.GetCommands(),
 		Cmd:      "scw registry logout program=docker",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -17,7 +19,7 @@ func Test_Logout(t *testing.T) {
 		OverrideExec: core.OverrideExecSimple("docker logout rg.fr-par.scw.cloud", 0),
 	}))
 	t.Run("podman", core.Test(&core.TestConfig{
-		Commands: GetCommands(),
+		Commands: registry.GetCommands(),
 		Cmd:      "scw registry logout program=podman",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
