@@ -1,8 +1,10 @@
-package vpc
+package vpc_test
 
 import (
 	"testing"
 
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
+
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/lb/v1"
@@ -11,7 +13,7 @@ import (
 )
 
 func Test_GetPrivateNetwork(t *testing.T) {
-	cmds := GetCommands()
+	cmds := vpc.GetCommands()
 	cmds.Merge(instance.GetCommands())
 	cmds.Merge(lb.GetCommands())
 	cmds.Merge(rdb.GetCommands())
