@@ -21,8 +21,22 @@ func CreateGatewayNetwork(metakey string) core.BeforeFunc {
 	)
 }
 
+func CreateGatewayNetworkDHCP(metakey string) core.BeforeFunc {
+	return core.ExecStoreBeforeCmd(
+		"GWNT",
+		"scw vpc-gw gateway-network create gateway-id={{ ."+metakey+".ID }} private-network-id={{ .PN.ID }} enable-dhcp=true dhcp-id={{ .DHCP.ID }} --wait",
+	)
+}
+
+func CreateDHCP() core.BeforeFunc {
+	return core.ExecStoreBeforeCmd(
+		"DHCP",
+		"scw vpc-gw dhcp create subnet=192.168.1.0/24 enable-dynamic=true",
+	)
+}
+
 func DeleteGatewayNetwork() core.AfterFunc {
-	return core.ExecAfterCmd("scw vpc-gw gateway-network delete {{ .GWNT.ID }}")
+	return core.ExecAfterCmd("scw vpc-gw gateway-network delete {{ .GWNT.ID }} --wait")
 }
 
 func DeleteGateway(metakey string) core.AfterFunc {
@@ -32,3 +46,7 @@ func DeleteGateway(metakey string) core.AfterFunc {
 func DeleteIPVpcGw(metakey string) core.AfterFunc {
 	return core.ExecAfterCmd("scw vpc-gw ip delete {{ ." + metakey + ".IP.ID }}")
 }
+
+func DeleteDHCP() core.AfterFunc {
+	return core.ExecAfterCmd("scw vpc-gw dhcp delete {{ .DHCP.ID }}")
+}
